#
# spec file for package QtAV
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname 1
%define Qt_name QtAV
%define ffmpeg_includedir -I%(pkg-config --variable=includedir libavutil)
Name:           QtAV
Version:        1.10.0
Release:        2.1
Summary:        Qt multimedia framework
License:        LGPL-2.1+ and GPL-3.0
Group:          Productivity/Multimedia/Other
Url:            http://qtav.org/
Source0:        https://github.com/wang-bin/QtAV/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  ImageMagick
BuildRequires:  dos2unix
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt4-devel
BuildRequires:  portaudio-devel
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavfilter)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavresample)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libpulse) >= 1.0
BuildRequires:  pkgconfig(libswresample)
BuildRequires:  pkgconfig(libswscale)
BuildRequires:  pkgconfig(libva)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(uchardet)
BuildRequires:  pkgconfig(xv)
BuildRequires:  update-desktop-files
Requires:       %{Qt_name}-players = %{version}

%description
QtAV is a multimedia playback library based on Qt and FFmpeg. It can help
you to write a player with less effort than ever before.

Features include:
   * Hardware decoding suppprt: DXVA2, VAAPI, VDA, CedarX, CUDA
   * OpenGL and ES2 support for Hi10P and other 16-bit YUV videos
   * Real time preview
   * Video capture in rgb and yuv format
   * OSD and custom filters
   * Subtitle
   * Transform video using GraphicsItemRenderer. (rotate, shear, etc)
   * Playing frame by frame (currently support forward playing)
   * Playback speed control
   * Variant streams: locale file, http, rtsp, etc.
   * Audio channel, tracks and external audio tracks
   * Dynamically change render engine when playing
   * Multiple video outputs for 1 player
   * Region of interest(ROI), i.e. video cropping
   * Video eq: brightness, contrast, saturation, hue
   * QML support as a plugin. Most playback APIs are compatible with
     QtMultiMedia module

%package -n     lib%{Qt_name}%{soname}
Summary:        QtAV library
Group:          System/Libraries

%description -n lib%{Qt_name}%{soname}
QtAV is a multimedia playback library based on Qt and FFmpeg.

This package contains the QtAV library.

%package -n     lib%{Qt_name}Widgets%{soname}
Summary:        QtAV Widgets module
Group:          System/Libraries

%description -n lib%{Qt_name}Widgets%{soname}
QtAV is a multimedia playback library based on Qt and FFmpeg.

This package contains a set of widgets to play media.

%package -n     %{Qt_name}-players
Summary:        QtAV/QML players
Group:          Productivity/Multimedia/Video/Players
Requires:       lib%{Qt_name}Widgets%{soname} = %{version}

%description -n	%{Qt_name}-players
QtAV is a multimedia playback library based on Qt and FFmpeg.

This package contains the QtAV based players.

%package -n		%{Qt_name}-devel
Summary:        QtAV development files
Group:          Development/Libraries/C and C++
Requires:       lib%{Qt_name}Widgets%{soname} = %{version}
BuildRequires:  libqt4-devel

%description -n %{Qt_name}-devel
This package contains the header development files for building some QtAV
applications using QtAV headers.

%prep
%setup -q

# Fix incorrect sRGB profile
for f in $(find . -type f -name \*.png); do
convert $f -strip $f
done

BUILD_TIME=$(LC_ALL=C date -ur %{_sourcedir}/%{name}.changes +'%H:%M')
BUILD_DATE=$(LC_ALL=C date -ur %{_sourcedir}/%{name}.changes +'%b %d %Y')
grep -rl '__TIME__' . | xargs --verbose --no-run-if-empty \
sed -i "s/__TIME__/\"$BUILD_TIME\"/"
grep -rl '__DATE__' . | xargs --verbose --no-run-if-empty \
sed -i "s/__DATE__/\"$BUILD_DATE\"/"

# Fix files is compiled without RPM_OPT_FLAG
find . -type f -name \*.pro | while read FILE; do
echo "QMAKE_CXXFLAGS += %{optflags} %{ffmpeg_includedir}" >> "$FILE"; done

%build
mkdir build
pushd build
qmake "CONFIG+=no_rpath recheck" ../QtAV.pro
make %{?_smp_mflags} PREFIX=/usr
popd

%install
pushd build
%make_install INSTALL_ROOT=%{buildroot}
popd

install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{_libdir}/qt/bin
install -d %{buildroot}%{_datadir}/icons/hicolor/scalable/apps

mv %{buildroot}%{_bindir}/* %{buildroot}%{_libdir}/qt/bin/
ln -s %{_libdir}/qt/bin/player %{buildroot}%{_bindir}/Player
mv %{buildroot}%{_datadir}/icons/hicolor/{64x64/apps,scalable/apps}/QtAV.svg

printf 'lib%{Qt_name}%{soname}\n
lib%{Qt_name}Widgets%{soname}\n' > %{_sourcedir}/baselibs.conf

dos2unix -k README.md
dos2unix -k %{buildroot}%{_datadir}/applications/player.desktop

find %{buildroot} -name \*.a -exec rm {} \;
# Duplicate files
rm -rf  %{buildroot}%{_datadir}/doc

%post -n %{Qt_name}-players %desktop_database_post
%postun -n %{Qt_name}-players %desktop_database_postun

%post -n  lib%{Qt_name}%{soname} -p /sbin/ldconfig
%postun -n  lib%{Qt_name}%{soname} -p /sbin/ldconfig

%post -n lib%{Qt_name}Widgets%{soname} -p /sbin/ldconfig
%postun -n lib%{Qt_name}Widgets%{soname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc Changelog  gpl-3.0* lgpl-2.1* README*

%files -n lib%{Qt_name}%{soname}
%defattr(-,root,root)
%{_libdir}/lib%{Qt_name}.so.*

%files -n lib%{Qt_name}Widgets%{soname}
%defattr(-,root,root)
%{_libdir}/lib%{Qt_name}Widgets.so.*

%files -n %{Qt_name}-players
%defattr(-,root,root)
%{_bindir}/Player
%dir %{_libdir}/qt
%dir %{_libdir}/qt/bin
%{_libdir}/qt/bin/player
%{_datadir}/applications/player.desktop
%{_datadir}/icons/hicolor/scalable/apps/QtAV.svg

%files -n %{Qt_name}-devel
%defattr(-,root,root)
%{_libdir}/lib%{Qt_name}.so
%{_libdir}/lib%{Qt_name}.prl
%{_libdir}/lib%{Qt_name}Widgets.so
%{_libdir}/lib%{Qt_name}Widgets.prl
%dir %{_libdir}/qt
%dir %{_libdir}/qt/bin
%{_libdir}/qt/bin/libcommon.prl
%{_includedir}/Config.h
%{_includedir}/ScreenSaver.h
%{_includedir}/common.h
%{_includedir}/common_export.h
%{_includedir}/qoptions.h
%{_includedir}/QtAV
%{_includedir}/QtAVWidgets
%{_datadir}/qt4/mkspecs/features/av.prf
%{_datadir}/qt4/mkspecs/features/avwidgets.prf

%changelog
* Wed Mar  2 2016 avvissu@yandex.ru
- Fix desktopfile-without-binary
* Wed Mar  2 2016 avvissu@yandex.ru
- Update to 1.10.0:
  * see: /usr/share/doc/packages/QtAV/ChangeLog
* Mon Dec 21 2015 avvissu@yandex.ru
- Update to 1.9.0:
  * see: /usr/share/doc/packages/QtAV/ChangeLog
- Remove patches:
  * QtAV-1.8.0_link_libraries.patch (fixed in upstream)
* Thu Dec 10 2015 avvissu@yandex.ru
- Fix build errors with ffmpeg: define ffmpeg_includedir
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for some BuildRequires
* Sun Sep 13 2015 avvissu@yandex.ru
- Use predefined RPM macros from /etc/rpm/macros.qt5
- Add QtAV-1.8.0_link_libraries.patch
- Add BuildRequires: kf5-filesystem
* Wed Sep  2 2015 avvissu@yandex.ru
- Update to 1.8.0:
  * see: /usr/share/doc/packages/QtAV/ChangeLog
- Remove QtAV-1.6.0_qreal.patch (fixed in upstream)
* Thu Jun 11 2015 avvissu@yandex.ru
- Fix build on openSUSE > 13.2:
  * use original name of project (Qt5AV -> QtAV)
* Sat May 30 2015 avvissu@yandex.ru
- Add conflicts: %%%%name-players for different Qt versions
- Execute %%%%desktop_database_post(postun) only for %%%%name-players
* Wed May  6 2015 avvissu@yandex.ru
- Fix files is compiled without RPM_OPT_FLAG
* Sun Apr 26 2015 avvissu@yandex.ru
- Fix build on arm (QtAV-1.6.0_qreal.patch)
- Fix incorrect sRGB profile
- Drop QtAV-1.5.0_rpath.patch (fixed)
* Sat Apr 25 2015 avvissu@yandex.ru
- Update to 1.6.0:
- OpenGL:
  * PBO support (enable by enviroment var QTAV_PBO=1)
  * rectangle texture support
  * packed yuv formats support
  * support buffer progress, buffer value control
- Support frame rate setup
- Support RAW streams, such as h264, yuv
- Audio filter support
- Better libavfilter support
- Add pulseaudio support
- Detect volume change by per-app volume control
- player/QMLPlayer:
  * decoder detail
  * more options: preview config, buffer, fps, timeout
- Use CONFIG+=no_rpath instead of QtAV-1.5.0_rpath.patch
* Wed Apr  1 2015 avvissu@yandex.ru
- Build with Qt4 on openSUSE < 13.2:
  * change QtAV.spec for build with Qt4
  * add BuildRequires: libqt4-devel
- Add Qt5AV.spec:
  * [fixed] module "QtQuick.Dialogs" is not installed:
  add Requires: libqt5-qtquickcontrols Qt5AV-qml
- Fix error while loading shared libraries:
  * change QtAV-1.5.0_rpath.patch
  * set the environment variable $BINDIR and $QMLDIR
- Add 32-bit packages for 64-bit environment
* Sun Mar 29 2015 avvissu@yandex.ru
- Initial release
